﻿using System;
using System.Collections.Generic;
using System.Text;

using EllieMae.Encompass.ComponentModel;
using EllieMae.Encompass.Automation;
using EllieMae.Encompass.BusinessObjects.Loans;

namespace CxNowAtLoanOpenAndSave
{
    [Plugin]
    public class EncompassPlugin
    {
        // Constructor - handle Loan Open and Loan Closing events
        public EncompassPlugin()
        {
            EncompassApplication.LoanOpened += new EventHandler(LoanOpenedEvent);
            EncompassApplication.LoanClosing += new EventHandler(LoanClosingEvent);
        }

        // Loan Opened event - start monitoring BeforeCommit
        private void LoanOpenedEvent(object sender, EventArgs e)
        {
            EncompassApplication.CurrentLoan.BeforeCommit += new CancelableEventHandler(BeforeCommitEvent);
            SetCxNowField();
        }

        // Loan Closing event - stop monitoring BeforeCommit
        private void LoanClosingEvent(object sender, EventArgs e)
        {
            EncompassApplication.CurrentLoan.BeforeCommit -= new CancelableEventHandler(BeforeCommitEvent);
        }

        // Before Commit - set CX.NOW = Now so that stuff can trigger off it
        private void BeforeCommitEvent(object source, CancelableEventArgs e)
        {
            SetCxNowField();
        }

        // Set [CX.NOW] field - must be STRING 20-character
        private void SetCxNowField()
        {
            try
            {
                Loan loan = EncompassApplication.CurrentLoan;
                if (loan != null)
                {
                    loan.Fields["CX.NOW"].Value = DateTime.Now.ToString("MM/dd/yyyy HH:mm:ss");
                }
            }
            catch (Exception ex)
            {
                System.Windows.Forms.MessageBox.Show("SetCxNowField Error: " + ex.Message);
            }
        }

    }
}
